==> libfwbuilder-3.0.1.tar.gz: libfwbuilder-3.0.1/src/fwbuilder/NetworkIPv6.h <==
/* 

                          Firewall Builder

                 Copyright (C) 2008 NetCitadel, LLC

  Author:  Vadim Kurland     vadim@vk.crocodile.org

  $Id: NetworkIPv6.h 166 2008-08-03 18:18:06Z vadim $


  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

#ifndef __NETWORKIPV6_HH_FLAG__
#define __NETWORKIPV6_HH_FLAG__

#include <fwbuilder/Address.h>
#include <fwbuilder/InetAddrMask.h>
#include <fwbuilder/InetAddr.h>
#include <fwbuilder/InetAddrMask.h>

namespace libfwbuilder
{

    class NetworkIPv6 : public Address
{
public:
    
    NetworkIPv6();
    NetworkIPv6(const FWObject *root,bool prepopulate);
    NetworkIPv6(NetworkIPv6 &);
    NetworkIPv6(const std::string &);
    virtual ~NetworkIPv6();

    bool isValidRoutingNet() const;

    virtual void       fromXML (xmlNodePtr parent) throw(FWException);
    virtual xmlNodePtr toXML   (xmlNodePtr xml_parent_node) throw(FWException);
    
    DECLARE_FWOBJECT_SUBTYPE(NetworkIPv6);

    virtual FWObject& shallowDuplicate(const FWObject *obj,
                                       bool preserve_id = true)
        throw(FWException);

    virtual bool hasInetAddress() const { return true; }

    virtual const Address* getAddressObject() const { return this; }

    virtual void setAddress(const InetAddr &a);
    virtual void setNetmask(const InetAddr &nm);
    virtual void setAddressNetmask(const std::string& s);

};

}

#endif // __NETWORK_HH_FLAG__

==> libfwbuilder_3.0.7.orig.tar.gz: libfwbuilder-3.0.7/src/fwbuilder/NetworkIPv6.h <==
/* 

                          Firewall Builder

                 Copyright (C) 2008 NetCitadel, LLC

  Author:  Vadim Kurland     vadim@fwbuilder.org

  $Id: NetworkIPv6.h 236 2008-12-25 20:36:41Z vadim $


  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

#ifndef __NETWORKIPV6_HH_FLAG__
#define __NETWORKIPV6_HH_FLAG__

#include <fwbuilder/Address.h>
#include <fwbuilder/InetAddrMask.h>
#include <fwbuilder/InetAddr.h>
#include <fwbuilder/InetAddrMask.h>
#include <fwbuilder/ObjectMatcher.h>

namespace libfwbuilder
{

    class NetworkIPv6 : public Address
{
public:
    
    NetworkIPv6();
    NetworkIPv6(const FWObjectDatabase *root,bool prepopulate);
    NetworkIPv6(NetworkIPv6 &);
    NetworkIPv6(const std::string &);
    virtual ~NetworkIPv6();

    bool isValidRoutingNet() const;

    virtual void       fromXML (xmlNodePtr parent) throw(FWException);
    virtual xmlNodePtr toXML   (xmlNodePtr xml_parent_node) throw(FWException);
    
    DECLARE_FWOBJECT_SUBTYPE(NetworkIPv6);

    virtual FWObject& shallowDuplicate(const FWObject *obj,
                                       bool preserve_id = true)
        throw(FWException);

    virtual bool hasInetAddress() const { return true; }

    /**
     * similar to hasInetAddress() but counts addresses
     */
    virtual int countInetAddresses(bool) const { return 1; }
    
    virtual const Address* getAddressObject() const { return this; }

    virtual void setAddress(const InetAddr &a);
    virtual void setNetmask(const InetAddr &nm);
    virtual void setAddressNetmask(const std::string& s);

    virtual bool isPrimaryObject() const { return true; }

    virtual bool dispatchComplexMatch(ObjectMatcher *om, FWObject *obj)
    { return om->checkComplexMatch(this, obj); }
};

}

#endif // __NETWORK_HH_FLAG__
